==> CGAL-6.0-doc_html.tar.xz: doc_html/Polygon_mesh_processing/group__PMP__measure__grp.js <==
var group__PMP__measure__grp =
[
    [ "CGAL::Polygon_mesh_processing::area", "group__PMP__measure__grp.html#gadcc6926cfa00708e48d006074ce69c22", null ],
    [ "CGAL::Polygon_mesh_processing::area", "group__PMP__measure__grp.html#ga8124de2121266ce57f9ad71de570cf5d", null ],
    [ "CGAL::Polygon_mesh_processing::centroid", "group__PMP__measure__grp.html#gae1b5dbd88bbd5b58517e685ee4e0172c", null ],
    [ "CGAL::Polygon_mesh_processing::edge_length", "group__PMP__measure__grp.html#gaaffc67e631d83a7da4b1096b782ead94", null ],
    [ "CGAL::Polygon_mesh_processing::face_area", "group__PMP__measure__grp.html#ga28ad46d585ae505c6f6696b1af9b18ae", null ],
    [ "CGAL::Polygon_mesh_processing::face_aspect_ratio", "group__PMP__measure__grp.html#gaf643adc62ed10ec185c67f611378ef77", null ],
    [ "CGAL::Polygon_mesh_processing::face_border_length", "group__PMP__measure__grp.html#ga3cb8dd4133e21dc9f6db97d2f50cc3f0", null ],
    [ "CGAL::Polygon_mesh_processing::longest_border", "group__PMP__measure__grp.html#ga90dc3dc18ae03b37e825f6b4b4ee2dd0", null ],
    [ "CGAL::Polygon_mesh_processing::match_faces", "group__PMP__measure__grp.html#ga654cb1da1be38e141b6340bd33aaf66f", null ],
    [ "CGAL::Polygon_mesh_processing::squared_edge_length", "group__PMP__measure__grp.html#ga36667883a2aea525e578f95100006ab5", null ],
    [ "CGAL::Polygon_mesh_processing::squared_face_area", "group__PMP__measure__grp.html#ga03162f7ecf67254f318a230b6dad3653", null ],
    [ "CGAL::Polygon_mesh_processing::volume", "group__PMP__measure__grp.html#ga1190f04c4b91b33cbb13f4f429c50005", null ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Polygon_mesh_processing/group__PMP__measure__grp.js <==
var group__PMP__measure__grp =
[
    [ "CGAL::Polygon_mesh_processing::angle_sum", "group__PMP__measure__grp.html#ga25d3836c21931610cf76b6716a06254c", null ],
    [ "CGAL::Polygon_mesh_processing::area", "group__PMP__measure__grp.html#gadcc6926cfa00708e48d006074ce69c22", null ],
    [ "CGAL::Polygon_mesh_processing::area", "group__PMP__measure__grp.html#ga8124de2121266ce57f9ad71de570cf5d", null ],
    [ "CGAL::Polygon_mesh_processing::centroid", "group__PMP__measure__grp.html#gae1b5dbd88bbd5b58517e685ee4e0172c", null ],
    [ "CGAL::Polygon_mesh_processing::discrete_Gaussian_curvature", "group__PMP__measure__grp.html#ga11a2d646d4636605d185653bff5bbbbb", null ],
    [ "CGAL::Polygon_mesh_processing::discrete_Gaussian_curvatures", "group__PMP__measure__grp.html#ga902f60c6d4bcb13c0583be6ed40e71e6", null ],
    [ "CGAL::Polygon_mesh_processing::discrete_mean_curvature", "group__PMP__measure__grp.html#ga1a31fa9412b4643dc7202a54246db78b", null ],
    [ "CGAL::Polygon_mesh_processing::discrete_mean_curvatures", "group__PMP__measure__grp.html#ga18fe36d21838ea95b42abb0f5cb6d026", null ],
    [ "CGAL::Polygon_mesh_processing::edge_length", "group__PMP__measure__grp.html#gaaffc67e631d83a7da4b1096b782ead94", null ],
    [ "CGAL::Polygon_mesh_processing::face_area", "group__PMP__measure__grp.html#ga28ad46d585ae505c6f6696b1af9b18ae", null ],
    [ "CGAL::Polygon_mesh_processing::face_aspect_ratio", "group__PMP__measure__grp.html#gaf643adc62ed10ec185c67f611378ef77", null ],
    [ "CGAL::Polygon_mesh_processing::face_border_length", "group__PMP__measure__grp.html#ga3cb8dd4133e21dc9f6db97d2f50cc3f0", null ],
    [ "CGAL::Polygon_mesh_processing::longest_border", "group__PMP__measure__grp.html#ga90dc3dc18ae03b37e825f6b4b4ee2dd0", null ],
    [ "CGAL::Polygon_mesh_processing::match_faces", "group__PMP__measure__grp.html#ga654cb1da1be38e141b6340bd33aaf66f", null ],
    [ "CGAL::Polygon_mesh_processing::squared_edge_length", "group__PMP__measure__grp.html#ga36667883a2aea525e578f95100006ab5", null ],
    [ "CGAL::Polygon_mesh_processing::squared_face_area", "group__PMP__measure__grp.html#ga03162f7ecf67254f318a230b6dad3653", null ],
    [ "CGAL::Polygon_mesh_processing::volume", "group__PMP__measure__grp.html#ga1190f04c4b91b33cbb13f4f429c50005", null ]
];
